# 通过分析《程序设计书_XXXX.md》,帮我按照如下规则生成对应的文件:

    1. 生成数据结构文件,创建到指定目录文件下
    2. 生成RPC文件,创建到指定目录文件下
    3. 生成API接口文件,创建到指定目录文件下
    4. 生成测试RPC代码,创建到指定目录文件下
    5. 生成readme.md的文档

具体内容如下:

## 1. 生成数据结构文件,创建到指定目录文件下

数据结构范例如下:

```rs
// 参数结构体
struct RequestParam {
    #[default=0]
    param1: u32,          // 参数1
    #[default='']
    param2: str,          // 参数2
}

// 数据对象结构体
struct RecordData {
    #[default=0]
    data1: u32,          // 数据1
    #[default='']
    data2: str,          // 数据2
    #[default=[]]
    data2: [u32],        // 数据3
}

// 需要落地的DataBase                                                                        
#[primary=key,db=logfile,dbMonitor=true]
struct PlayerXxxDB {
    
    key: u32,                           // PlayerXxxDB的主键

    #[default=new Map()]
    map: HashMap<u32, [u32]>,           // 需要存储的map数据
    
    data: Option<RecordData>,           // 需要存储的结构体RecordData数据
}
```

说明：
- 每个字段都要有注释
- 结构体用驼峰命名法,首字母大写,其余单词首字母大写
- 结构体包含的字段使用小写字母,单词之间使用下划线连接
- 结构体应该简洁明了,避免使用冗长的命名,英文字母不超过22个
- 变量需要给默认的值,默认值需要使用#[default=xxx]来指定
- DB的主键不需要给默认值,需要设置primary=key
- 可为空的字段需要加Option,例如Option<u32>,Option<RecordData>
- 生成的数据结构文件放在`./src/struct`目录下,文件名为`xxx.rs`,xxx为《程序设计书_XXXX.md》中的'功能名'


### 2. 生成RPC文件,创建到指定目录文件下

RPC范例如下:

```ts
// 导入模块
import { Tr } from "pi_ucore/db/mgr";
import { Env } from "pi_ucore/db/env";
import { getCurrentRid } from "pi_common_tools/main";
import { read, write } from "pi_common_tools/util/db_tool";
import { RequestParam } from 'NPM模块名 + /struct/ + 功能名 + .rs';
import { sendMessageToServer, doLocalAndServer } from 'NPM模块名 + /api';

//-----------------------------------------------------------------------
// 
// getXxxDBRpc                     客户端读取数据库Rpc
// sendMessageToServerRpc          客户端向服务器端发消息服务器端执行Rpc
// doLocalAndServerRpc             客户端向服务器端发消息服务器端执行同时客户端本地执行Rpc
// 
//-----------------------------------------------------------------------

// 客户端读取数据库Rpc
// #[rpc=rpcServer, src=*,rpcWrapper=read,rpcMode=check]
export const getXxxDBRpc = async (tr: Tr, uid: number) => {
    // 读数据库的方法
    let xxxDB = await read(tr, XxxDB, uid) as XxxDB;
    return xxxDB; // 返回数据库结构体
}

// 客户端向服务器端发消息服务器端执行Rpc
// #[rpc=rpcServer, src=*,rpcMode=remote, rpcWrapper=write]
export const sendMessageToServerRpc = async (tr: Tr, uid: number) => {
    let param = new RequestParam(); // 参数结构体
    param.param1 = 1;   // 参数1
    param.param2 = "2"; // 参数2
    // 执行API方法,向服务器端发消息
    let r = await sendMessageToServer(tr, uid, param);
    return r;
}

// 客户端向服务器端发消息服务器端执行同时客户端本地执行Rpc
// #[rpc=rpcServer, src=*,rpcMode=fork, rpcWrapper=write]
export const doLocalAndServerRpc = async (tr: Tr, uid: number, addUids: number[]) => {
    // 执行API方法
    let r = await doLocalAndServer(tr, uid, addUids);
    return r; // 返回结果
}
```

说明：
- 每三行最少要有一行注释,来解释说明代码逻辑和字段含义
- 函数名用驼峰命名法,首字母小写,其余单词首字母大写
- 函数名应该具有描述性,能够清楚地表达函数的功能和用途
- 函数名应该简洁明了,避免使用冗长的变量名,英文字母不超过22个
- 客户端执行的函数rpcMode需要设置为check,服务器执行的函数rpcMode需要设置为remote
- 客户端,服务器端同时执行的函数rpcMode需要设置为fork
- 函数只读操作rpcWrapper设置为read,函数写操作rpcWrapper设置为write
- 生成的注释格式参考上述RPC范例,注意不要有多余的空行
- 每个Rpc函数不要过于冗余,行数尽量不要超过50行,每行结束要有分号
- 每个Rpc函数要提出api接口为了方便服务器直接进行测试,比如getXxxDBRpc的api接口为getXxxDB,sendMessageToServerRpc的接口为sendMessageToServer
- import导入是,要写完整的路径,比如PlayerXxxDB的引入路径就要写成'import { PlayerXxxDB } from "game_xxxx_server/struct/xxxx.struct"',game_xxxx_server是'NPM模块名',xxxx是'功能名'
- 生成的通讯协议RPC文件放在`./src/rpc`目录下,文件名为`xxx.event.ts`,xxx为《程序设计书_XXXX.md》中的'功能名'
- RPC文件里要自动导入三个包Tr,Env, getCurrentRid


## 3. 生成API接口文件,创建到指定目录文件下

配置表xls文件范例

```excel
| 配置表名 | 配置表id | 名称     | 描述 |
|---------|----------|---------|------|
| $XxxCfg | id       | name    | desc |
|         | u32      | str     | str  |
|         | 1001     | 名称1  | 描述1  |
|         | 1002     | 名称2  | 描述2  |
|         | 1003     | 名称3  | 描述3  |
```

API接口范例如下:

```ts
import { getCfg, getAllCfg, writes } from "pi_common_tools/util/db_tool";
import { costProps, sendAwards } from 'pi_award/api';

//-----------------------------------------------------------------------
// 
// sendMessageToServer          客户端向服务器端发消息服务器端执行API
// doLocalAndServer             客户端向服务器端发消息服务器端执行同时客户端本地执行API
// 
//-----------------------------------------------------------------------

/**
 * @name 客户端向服务器端发消息服务器端执行API
 * 
 * @param tr            事务对象
 * @param uid           玩家唯一UID
 * @param param        参数RequestParam
 * 
 * @return true
 */
export const sendMessageToServer = async (tr: Tr, uid: number, param: RequestParam) => {
    let param1 = param.param1;
    let param2 = param.param2;
    // 按照《程序设计书_XXXX.md》要求进行业务处理
    // TODO
    // ......
    return true; // 返回结果
}

/**
 * @name 客户端向服务器端发消息服务器端执行同时客户端本地执行API
 * 
 * @param tr            事务对象
 * @param uid           玩家唯一UID
 * @param addUids       数组参数addUids
 * 
 * @return true
 */
export const doLocalAndServer = async (tr: Tr, uid: number, addUids: number[]) => {
    
    for (let addUid of addUids) {
        // 按照《程序设计书_XXXX.md》要求进行业务处理
        // TODO
        // ......
    }

    // 读xls配置表操作
    let cfg = getCfg(XxxCfg, 配置表id) as XxxCfg;
    // 读多xls配置表操作
    let cfgMap = getAllCfg(XxxCfg) as Map<number, XxxCfg>;

    // 读DB数据操作
    let xxxDB = await read(tr, PlayerXxxDB, uid) as PlayerXxxDB;
    // 写DB数据操作
    let r = await write(tr, PlayerXxxDB, uid, xxxDB);
    // 写多个DB的操作
    await writes(tr, [
        [DB1, db1.key, db1],
        [DB2, db1.key, db2],
        ...
    ]);
    // 发道具操作
    let addItems = [[道具模版id1, 道具数量],[道具模版id1, 道具数量],...];
    await sendAwards(tr, uid, addItems);
    // 扣除道具操作
    let costItems = [[道具模版id1, 道具数量],[道具模版id1, 道具数量],...];
    let r = await costProps(tr, uid, costItems);

    return true;
}
```

说明：
- API接口文件的规约和rpc文件一样
- 生成的注释格式参考上述API范例
- 生成的API接口文件放在`./src`目录下,文件名固定为`api.ts`


## 4. 生成测试RPC代码,创建到指定目录文件下

测试RPC范例如下:

```ts
import { Tr } from 'pi_ucore/db/mgr';
import { Env } from 'pi_ucore/db/env';
declare var env: Env;

//-----------------------------------------------------------------------
// 
// testSendMessageToServerRpc          测试客户端向服务器端发消息服务器端执行Rpc
// 
//-----------------------------------------------------------------------

// #[event=NPM模块名_test_send_message_to_server_rpc, src=pid_rpc, management_plugin_name=NPM模块名, auth=rw] 测试客户端向服务器端发消息服务器端执行Rpc
export const testSendMessageToServerRpc = async (_eventName: string, arg: any) => {

    let param = new RequestParam(); // 参数结构体
    param.param1 = arg.param1;      // 参数1
    param.param2 = arg.param2;      // 参数2
    await env.dbMgr.write(async (tr: Tr) => {
        //测试模块 此处给出打印
        console.log('NPM模块名 testSendMessageToServerRpc arg = ', arg)
        // 执行API方法,向服务器端发消息
        let r = await sendMessageToServer(tr, uid, param);
        console.log('NPM模块名 testSendMessageToServerRpc r = ', r)
    })
    return true;
}
```

说明：
1. 所有的RPC函数都要给出对应的testRpc测试函数,函数的命名就是test+Rpc函数名,参数为固定的(_eventName: string, arg: any)
2. 测试rpc需要有描述注释#[event=NPM模块名_test_send_message_to_server_rpc, src=pid_rpc, management_plugin_name=NPM模块名, auth=rw]
3. 其中management_plugin_name是NPM模块名,auth是读写权限,src是pid_rpc,event是'NPM模块名_'+testRpc的函数名(大写字母替换成_小写字母)
4. 每个测试testRpc都需要有打印日志,打印日志的格式为'NPM模块名 testRpc函数名 arg = ', arg
5. 只读RPC函数用'await env.dbMgr.read(async (tr: Tr) => { // api方法;  })';
6. 写入RPC函数用'await env.dbMgr.write(async (tr: Tr) => { // api方法;  })';
3. 生成的测试Rpc函数文件放在`./src/test`目录下,文件名固定为`test.event.ts`
4. 生成测试数据,需要给出边界值和异常值等测试数据


## 5. 生成readme.md的文档

1. 内容需要包括导入的包,依赖,使用说明,注意事项,所有的RPC,所有的API,涉及到的所有结构体
2. 分析npm功能的几个核心关键文件,帮我写一个Readme1.md的文档,要求文档内容包含功能概述,特性,导出的核心数据结构及核心方法,风险提示,QA等其他重要信息
3. 用markdown格式输出内容,生成Readme1.md文件,列举完所有的rpc,Api,导入模块import,不要遗漏