import { getCurrentRid } from "pi_common_tools/main";
import { Tr } from "pi_ucore/db/mgr";
import { getCfg, getAllCfg, writes } from "pi_common_tools/util/db_tool";
import { costProps, sendAwards , checkEnough } from 'pi_award/api';
import { read, write } from "pi_common_tools/util/db_tool";
import { LingBaoInstance, PlayerLingBaoDB } from "game_special_equip/struct/LingBaoSystem.struct";
import { LingBaoCfg , getStarGroupId } from "game_special_equip/xls/lingbao/lingbao_base.struct";
import { StarCfg } from "game_special_equip/xls/lingbao/lingbao_star.struct";
import { LingBaoChip } from "game_special_equip/xls/lingbao/lingbao_fragment.struct";

import { starUpLingBao, equipToHero, unequipFromHero, getEquipNum } from '../api';

//-----------------------------------------------------------------------
// 灵宝系统RPC接口
//-----------------------------------------------------------------------

// #[rpc=rpcServer, src=*,rpcWrapper=read,rpcMode=check]
export const checkStarUpConditionsRpc = async (tr: Tr, rid: number) => {
    const db = await read(tr, PlayerLingBaoDB, rid) as PlayerLingBaoDB;
    
    let redMap = new Map();

    for(let [k,v] of db.instances){
        let baseCfgInfo = getCfg(LingBaoCfg,v.special_instance_id);
        let groupId = getStarGroupId(baseCfgInfo.starGroup,v.star_level);
        let starCfgInfo = getCfg(StarCfg,groupId);
        if(!starCfgInfo.upCost || !starCfgInfo.upCost.length){
            continue
        }
        let r = await checkEnough(tr,rid,starCfgInfo.upCost);
        if(!r)continue;
        redMap.set(v.special_instance_id,1);
    }
    return redMap;
}


// #[rpc=rpcServer, src=*,rpcWrapper=read,rpcMode=check]
export const getPlayerLingBao = async (tr: Tr, rid: number) => {
    const db = await read(tr, PlayerLingBaoDB, rid) as PlayerLingBaoDB;
    return db;
}

// #[rpc=rpcServer, src=*,rpcWrapper=read,rpcMode=check]
export const getPlayerLingBaoNum = async (tr: Tr, rid: number) => {
    const r = await getEquipNum(tr, rid);
    return r;
}




// 灵宝升星
// #[rpc=rpcServer, src=*, rpcWrapper=write]
export const executeStarUpRpc = async (tr: Tr, rid: number, instanceId: number) => {
    if(isNaN(rid))return false;
    const result = await starUpLingBao(tr, rid, instanceId);
    return result;
}

//穿灵宝
// #[rpc=rpcServer, src=*,rpcWrapper=write]
export const equipLingBaoRpc = async (tr: Tr, rid: number, param) => {
    if(isNaN(rid))return false;
    // 执行远程装备操作
    const result = await equipToHero(tr, rid, param.heroId, param.instanceId);
    return result;
}

// #[rpc=rpcServer, src=*,rpcMode=remote, rpcWrapper=write]
export const unequipLingBaoRpc = async (tr: Tr, rid: number, heroId: number) => {
    if(isNaN(rid))return false;
    return await unequipFromHero(tr, rid, heroId);
}
